methodChannel property
The method channel used to interact with the native platform.
Implementation
@visibleForTesting
final methodChannel = const MethodChannel('zohodesk_portal_submit_ticket');
The method channel used to interact with the native platform.
@visibleForTesting
final methodChannel = const MethodChannel('zohodesk_portal_submit_ticket');